@@ -10,6 +10,7 @@ from .config import config, s3_config
 from .context import Context
 from .context_syntax import GLOBAL_CONTEXT
 from .dag import DAG
+from .op_template import get_k8s_core_v1_api
 from .step import Step
 from .steps import Steps
 from .task import Task
@@ -175,22 +176,8 @@ class Workflow:
                     s3_config["repo_prefix"] = s3["keyFormat"][:-len(t)]
 
     def get_k8s_core_v1_api(self):
-        if self.k8s_api_server is not None:
-            k8s_configuration = kubernetes.client.Configuration(
-                host=self.k8s_api_server)
-            k8s_configuration.verify_ssl = False
-            if self.token is None:
-                k8s_client = kubernetes.client.ApiClient(
-                    k8s_configuration)
-            else:
-                k8s_client = kubernetes.client.ApiClient(
-                    k8s_configuration, header_name='Authorization',
-                    header_value='Bearer %s' % self.token)
-            return kubernetes.client.CoreV1Api(k8s_client)
-        else:
-            kubernetes.config.load_kube_config(
-                config_file=self.k8s_config_file)
-            return kubernetes.client.CoreV1Api()
+        return get_k8s_core_v1_api(self.k8s_api_server, self.token,
+                                   self.k8s_config_file)
 
     def __enter__(self) -> 'Workflow':
         GLOBAL_CONTEXT.in_context = True
@@ -318,6 +305,7 @@ class Workflow:
             '/api/v1/workflows/%s' % self.namespace, 'POST',
             body=V1alpha1WorkflowCreateRequest(workflow=manifest),
             response_type=object,
+            header_params=config["http_headers"],
             _return_http_data_only=True)
         workflow = ArgoWorkflow(response)
 
@@ -501,11 +489,13 @@ class Workflow:
         try:
             response = self.api_instance.api_client.call_api(
                 '/api/v1/workflows/%s/%s' % (self.namespace, self.id),
-                'GET', response_type=object, _return_http_data_only=True)
+                'GET', response_type=object, _return_http_data_only=True,
+                header_params=config["http_headers"])
         except Exception:
             response = self.api_instance.api_client.call_api(
                 '/api/v1/archived-workflows/%s' % self.uid,
-                'GET', response_type=object, _return_http_data_only=True)
+                'GET', response_type=object, _return_http_data_only=True,
+                header_params=config["http_headers"])
         workflow = ArgoWorkflow(response)
         return workflow
 
@@ -639,11 +629,13 @@ class Workflow:
                 response = self.api_instance.api_client.call_api(
                     '/api/v1/workflows/%s/%s' % (self.namespace, self.id),
                     'GET', response_type=object, _return_http_data_only=True,
+                    header_params=config["http_headers"],
                     query_params=[('fields', 'status.outputs')])
             except Exception:
                 response = self.api_instance.api_client.call_api(
                     '/api/v1/archived-workflows/%s' % self.uid,
                     'GET', response_type=object, _return_http_data_only=True,
+                    header_params=config["http_headers"],
                     query_params=[('fields', 'status.outputs')])
             return [par["name"] for par in
                     response["status"]["outputs"]["parameters"]]
@@ -659,7 +651,7 @@ class Workflow:
             raise RuntimeError("Workflow ID is None")
         self.api_instance.api_client.call_api(
             '/api/v1/workflows/%s/%s/terminate' % (self.namespace, self.id),
-            'PUT')
+            'PUT', header_params=config["http_headers"])
 
     def delete(self) -> None:
         """
@@ -668,7 +660,8 @@ class Workflow:
         if self.id is None:
             raise RuntimeError("Workflow ID is None")
         self.api_instance.api_client.call_api(
-            '/api/v1/workflows/%s/%s' % (self.namespace, self.id), 'DELETE')
+            '/api/v1/workflows/%s/%s' % (self.namespace, self.id), 'DELETE',
+            header_params=config["http_headers"])
 
     def resubmit(self) -> None:
         """
@@ -678,7 +671,7 @@ class Workflow:
             raise RuntimeError("Workflow ID is None")
         self.api_instance.api_client.call_api(
             '/api/v1/workflows/%s/%s/resubmit' % (self.namespace, self.id),
-            'PUT')
+            'PUT', header_params=config["http_headers"])
 
     def resume(self) -> None:
         """
@@ -688,7 +681,7 @@ class Workflow:
             raise RuntimeError("Workflow ID is None")
         self.api_instance.api_client.call_api(
             '/api/v1/workflows/%s/%s/resume' % (self.namespace, self.id),
-            'PUT')
+            'PUT', header_params=config["http_headers"])
 
     def retry(self) -> None:
         """
@@ -698,7 +691,7 @@ class Workflow:
             raise RuntimeError("Workflow ID is None")
         self.api_instance.api_client.call_api(
             '/api/v1/workflows/%s/%s/retry' % (self.namespace, self.id),
-            'PUT')
+            'PUT', header_params=config["http_headers"])
 
     def stop(self) -> None:
         """
@@ -708,7 +701,7 @@ class Workflow:
             raise RuntimeError("Workflow ID is None")
         self.api_instance.api_client.call_api(
             '/api/v1/workflows/%s/%s/stop' % (self.namespace, self.id),
-            'PUT')
+            'PUT', header_params=config["http_headers"])
 
     def suspend(self) -> None:
         """
@@ -718,4 +711,4 @@ class Workflow:
             raise RuntimeError("Workflow ID is None")
         self.api_instance.api_client.call_api(
             '/api/v1/workflows/%s/%s/suspend' % (self.namespace, self.id),
-            'PUT')
+            'PUT', header_params=config["http_headers"])
